@@ -1,5 +1,8 @@
-use crate::identify::code_model::{CodeFile, Location, CodeFunction};
 use tree_sitter::{Node, QueryCapture};
+
+use guarding_core::domain::code_function::CodeFunction;
+use guarding_core::domain::code_file::CodeFile;
+use guarding_core::domain::Location;
 use crate::identify::rust_ident::RustIdent;
 
 pub trait CodeIdent {
